@@ -3,6 +3,9 @@
 
 #include <QWidget>
 #include <QDebug>
+#ifdef Q_WS_MAEMO_5
+#include <QMaemo5InformationBox>
+#endif
 #include "globals.h"
 #include "slidewidget.h"
 
